@@ -37,8 +37,7 @@ CursorType = Union[DictCursor, RealDictCursor, NamedTupleCursor]
 
 
 class PostgresHook(DbApiHook):
-    """
-    Interact with Postgres.
+    """Interact with Postgres.
 
     You can specify ssl parameters in the extra field of your connection
     as ``{"sslmode": "require", "sslcert": "/path/to/cert.pem", etc}``.
@@ -60,6 +59,9 @@ class PostgresHook(DbApiHook):
 
     :param postgres_conn_id: The :ref:`postgres conn id <howto/connection:postgres>`
         reference to a specific postgres database.
+    :param options: Optional. Specifies command-line options to send to the server
+        at connection start. For example, setting this to ``-c search_path=myschema``
+        sets the session's value of the ``search_path`` to ``myschema``.
     """
 
     conn_name_attr = "postgres_conn_id"
@@ -68,7 +70,7 @@ class PostgresHook(DbApiHook):
     hook_name = "Postgres"
     supports_autocommit = True
 
-    def __init__(self, *args, **kwargs) -> None:
+    def __init__(self, *args, options: str | None = None, **kwargs) -> None:
         if "schema" in kwargs:
             warnings.warn(
                 'The "schema" arg has been renamed to "database" as it contained the database name.'
@@ -81,6 +83,7 @@ class PostgresHook(DbApiHook):
         self.connection: Connection | None = kwargs.pop("connection", None)
         self.conn: connection = None
         self.database: str | None = kwargs.pop("database", None)
+        self.options = options
 
     @property
     def schema(self):
@@ -132,6 +135,9 @@ class PostgresHook(DbApiHook):
         if raw_cursor:
             conn_args["cursor_factory"] = self._get_cursor(raw_cursor)
 
+        if self.options:
+            conn_args["options"] = self.options
+
         for arg_name, arg_val in conn.extra_dejson.items():
             if arg_name not in [
                 "iam",
@@ -146,8 +152,8 @@ class PostgresHook(DbApiHook):
         return self.conn
 
     def copy_expert(self, sql: str, filename: str) -> None:
-        """
-        Executes SQL using psycopg2 copy_expert method.
+        """Executes SQL using psycopg2's ``copy_expert`` method.
+
         Necessary to execute COPY command without access to a superuser.
 
         Note: if this method is called with a "COPY FROM" statement and
@@ -169,8 +175,8 @@ class PostgresHook(DbApiHook):
                     conn.commit()
 
     def get_uri(self) -> str:
-        """
-        Extract the URI from the connection.
+        """Extract the URI from the connection.
+
         :return: the extracted uri.
         """
         conn = self.get_connection(getattr(self, self.conn_name_attr))
@@ -179,18 +185,19 @@ class PostgresHook(DbApiHook):
         return uri
 
     def bulk_load(self, table: str, tmp_file: str) -> None:
-        """Loads a tab-delimited file into a database table"""
+        """Loads a tab-delimited file into a database table."""
         self.copy_expert(f"COPY {table} FROM STDIN", tmp_file)
 
     def bulk_dump(self, table: str, tmp_file: str) -> None:
-        """Dumps a database table into a tab-delimited file"""
+        """Dumps a database table into a tab-delimited file."""
         self.copy_expert(f"COPY {table} TO STDOUT", tmp_file)
 
     @staticmethod
     def _serialize_cell(cell: object, conn: connection | None = None) -> Any:
-        """
-        Postgresql will adapt all arguments to the execute() method internally,
-        hence we return cell without any conversion.
+        """Serialize a cell.
+
+        PostgreSQL adapts all arguments to the ``execute()`` method internally,
+        hence we return the cell without any conversion.
 
         See http://initd.org/psycopg/docs/advanced.html#adapting-new-types for
         more information.
@@ -202,10 +209,11 @@ class PostgresHook(DbApiHook):
         return cell
 
     def get_iam_token(self, conn: Connection) -> tuple[str, str, int]:
-        """
-        Uses AWSHook to retrieve a temporary password to connect to Postgres
-        or Redshift. Port is required. If none is provided, default is used for
-        each service
+        """Get the IAM token.
+
+        This uses AWSHook to retrieve a temporary password to connect to
+        Postgres or Redshift. Port is required. If none is provided, the default
+        5432 is used.
         """
         try:
             from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
@@ -242,8 +250,7 @@ class PostgresHook(DbApiHook):
         return login, token, port
 
     def get_table_primary_key(self, table: str, schema: str | None = "public") -> list[str] | None:
-        """
-        Helper method that returns the table primary key
+        """Get the table's primary key.
 
         :param table: Name of the target table
         :param schema: Name of the target schema, public by default
@@ -267,9 +274,9 @@ class PostgresHook(DbApiHook):
     def _generate_insert_sql(
         cls, table: str, values: tuple[str, ...], target_fields: Iterable[str], replace: bool, **kwargs
     ) -> str:
-        """
-        Static helper method that generates the INSERT SQL statement.
-        The REPLACE variant is specific to PostgreSQL syntax.
+        """Generate the INSERT SQL statement.
+
+        The REPLACE variant is specific to the PostgreSQL syntax.
 
         :param table: Name of the target table
         :param values: The row to insert into the table
